==> production-demo-20260209_092413.tar.gz: var/www/html/production-demo/var/tmp/twig/d3/d31c4febbc53ab67916bae216cfa02cd.php <==
<?php

use Twig\Environment;
use Twig\Error\LoaderError;
use Twig\Error\RuntimeError;
use Twig\Extension\CoreExtension;
use Twig\Extension\SandboxExtension;
use Twig\Markup;
use Twig\Sandbox\SecurityError;
use Twig\Sandbox\SecurityNotAllowedTagError;
use Twig\Sandbox\SecurityNotAllowedFilterError;
use Twig\Sandbox\SecurityNotAllowedFunctionError;
use Twig\Source;
use Twig\Template;
use Twig\TemplateWrapper;

/* @bundles/CoreBundle/IpLookup/IP2LocationAPILookup.php */
class __TwigTemplate_88916e7db829d1d3fce1acb8a3d74af2 extends Template
{
    private Source $source;
    /**
     * @var array<string, Template>
     */
    private array $macros = [];

    public function __construct(Environment $env)
    {
        parent::__construct($env);

        $this->source = $this->getSourceContext();

        $this->parent = false;

        $this->blocks = [
        ];
    }

    protected function doDisplay(array $context, array $blocks = []): iterable
    {
        $macros = $this->macros;
        // line 1
        yield "<?php

namespace Mautic\\CoreBundle\\IpLookup;

class IP2LocationAPILookup extends AbstractRemoteDataLookup
{
    public function getAttribution(): string
    {
        return '<a href=\"http://IP2Location.com/\" target=\"_blank\">IP2Location </a> web service WS9 Package only.';
    }

    protected function getUrl(): string
    {
        return \"api.ip2location.com/?ip={\$this->ip}&key={\$this->auth}&package=WS9&format=json\";
    }

    protected function parseResponse(\$response)
    {
        try {
            \$record = json_decode(\$response);
            if (isset(\$record->country_name)) {
                \$this->country   = \$record->country_name;
                \$this->region    = \$record->region_name;
                \$this->city      = \$record->city_name;
                \$this->latitude  = \$record->latitude;
                \$this->longitude = \$record->longitude;
                // \$this->timezone  = \$record->location->timeZone;
                \$this->zipcode = \$record->zip_code;
            }
        } catch (\\Exception \$exception) {
            if (\$this->logger) {
                \$this->logger->warning('IP LOOKUP: '.\$exception->getMessage());
            }
        }
    }
}
";
        yield from [];
    }

    /**
     * @codeCoverageIgnore
     */
    public function getTemplateName(): string
    {
        return "@bundles/CoreBundle/IpLookup/IP2LocationAPILookup.php";
    }

    /**
     * @codeCoverageIgnore
     */
    public function getDebugInfo(): array
    {
        return array (  42 => 1,);
    }

    public function getSourceContext(): Source
    {
        return new Source("", "@bundles/CoreBundle/IpLookup/IP2LocationAPILookup.php", "/var/www/html/mauticGIT-Test/app/bundles/CoreBundle/IpLookup/IP2LocationAPILookup.php");
    }
}

==> production-demo-20260209_093043.tar.gz: var/www/html/production-demo/var/tmp/twig/d3/d31c4febbc53ab67916bae216cfa02cd.php <==
<?php

use Twig\Environment;
use Twig\Error\LoaderError;
use Twig\Error\RuntimeError;
use Twig\Extension\CoreExtension;
use Twig\Extension\SandboxExtension;
use Twig\Markup;
use Twig\Sandbox\SecurityError;
use Twig\Sandbox\SecurityNotAllowedTagError;
use Twig\Sandbox\SecurityNotAllowedFilterError;
use Twig\Sandbox\SecurityNotAllowedFunctionError;
use Twig\Source;
use Twig\Template;
use Twig\TemplateWrapper;

/* @bundles/CoreBundle/IpLookup/IP2LocationAPILookup.php */
class __TwigTemplate_88916e7db829d1d3fce1acb8a3d74af2 extends Template
{
    private Source $source;
    /**
     * @var array<string, Template>
     */
    private array $macros = [];

    public function __construct(Environment $env)
    {
        parent::__construct($env);

        $this->source = $this->getSourceContext();

        $this->parent = false;

        $this->blocks = [
        ];
    }

    protected function doDisplay(array $context, array $blocks = []): iterable
    {
        $macros = $this->macros;
        // line 1
        yield "<?php

namespace Mautic\\CoreBundle\\IpLookup;

class IP2LocationAPILookup extends AbstractRemoteDataLookup
{
    public function getAttribution(): string
    {
        return '<a href=\"http://IP2Location.com/\" target=\"_blank\">IP2Location </a> web service WS9 Package only.';
    }

    protected function getUrl(): string
    {
        return \"api.ip2location.com/?ip={\$this->ip}&key={\$this->auth}&package=WS9&format=json\";
    }

    protected function parseResponse(\$response)
    {
        try {
            \$record = json_decode(\$response);
            if (isset(\$record->country_name)) {
                \$this->country   = \$record->country_name;
                \$this->region    = \$record->region_name;
                \$this->city      = \$record->city_name;
                \$this->latitude  = \$record->latitude;
                \$this->longitude = \$record->longitude;
                // \$this->timezone  = \$record->location->timeZone;
                \$this->zipcode = \$record->zip_code;
            }
        } catch (\\Exception \$exception) {
            if (\$this->logger) {
                \$this->logger->warning('IP LOOKUP: '.\$exception->getMessage());
            }
        }
    }
}
";
        yield from [];
    }

    /**
     * @codeCoverageIgnore
     */
    public function getTemplateName(): string
    {
        return "@bundles/CoreBundle/IpLookup/IP2LocationAPILookup.php";
    }

    /**
     * @codeCoverageIgnore
     */
    public function getDebugInfo(): array
    {
        return array (  42 => 1,);
    }

    public function getSourceContext(): Source
    {
        return new Source("", "@bundles/CoreBundle/IpLookup/IP2LocationAPILookup.php", "/var/www/html/production-demo/app/bundles/CoreBundle/IpLookup/IP2LocationAPILookup.php");
    }
}
